@@ -3,7 +3,7 @@ from avi.sdk.avi_api import ApiSession, \
 import requests
 import re
 import urllib
-import urlparse
+# import urlparse
 import json
 from datetime import datetime
 from requests import ConnectionError
@@ -43,7 +43,7 @@ class OneloginSAMLApiSession(ApiSession):
                  retry_conxn_errors=True, data_log=False,
                  avi_credentials=None, session_id=None, csrftoken=None,
                  lazy_authentication=False, max_api_retries=None,
-                 idp_cookies=None):
+                 idp_cookies=None,user_hdrs=None):
         """
         This extends ApiSession class and overrides authentication method
         for SMAL authentication.
@@ -77,7 +77,7 @@ class OneloginSAMLApiSession(ApiSession):
             port, timeout, api_version,
             retry_conxn_errors, data_log,
             avi_credentials, session_id, csrftoken,
-            lazy_authentication, max_api_retries)
+            lazy_authentication, max_api_retries, user_hdrs)
         return
 
     def saml_assertion(self, username, password):
@@ -387,10 +387,10 @@ class OktaSAMLApiSession(ApiSession):
 
         idp_session = requests.Session()
         idp_session.verify = False
-        saml_data = urllib.urlencode({
+        saml_data = urllib.parse.urlencode({
             'SAMLRequest': saml_request,
             'RelayState': relay_state})
-        parsed_uri = urlparse.urlparse(assertion_url)
+        parsed_uri = urllib.parse.urlparse(assertion_url)
         base_url = "{}://{}".format(parsed_uri.scheme, parsed_uri.netloc)
         if self.idp_cookies:
             logger.info("Controller url %s generated SAML request is being "
